#
# spec file for package lib3270
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) <2008> <Banco do Brasil S.A.>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lib3270
Version:        5.3
Release:        bp154.1.159
Summary:        TN3270 Access library
License:        LGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/PerryWerneck/lib3270
Source:         %{name}-%{version}.tar.xz
Patch0:         fix-crl-get-engine.patch
BuildRequires:  autoconf >= 2.61
BuildRequires:  automake
BuildRequires:  binutils
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  m4
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(openssl)

%if 0%{?centos_version}
# CENTOS Requires gdb for debuginfo
BuildRequires:  gdb
%endif

%description
TN3270 access library, originally designed as part of the pw3270 application.

For more details, see https://softwarepublico.gov.br/social/pw3270/ .

%define MAJOR_VERSION %(echo %{version} | cut -d. -f1)
%define MINOR_VERSION %(echo %{version} | cut -d. -f2 | cut -d+ -f1)
%define _libvrs %{MAJOR_VERSION}_%{MINOR_VERSION}

%package -n %{name}-%{_libvrs}
Summary:        TN3270 Access library
Group:          Development/Libraries/C and C++

%description -n %{name}-%{_libvrs}
TN3270 access library, originally designed as part of the pw3270 application.

For more details, see https://softwarepublico.gov.br/social/pw3270/ .

%package devel
Summary:        TN3270 Access library development files
Group:          Development/Libraries/C and C++
Requires:       %{name}-%{_libvrs} = %{version}

%description devel
Header files for the TN3270 access library.

%prep
%setup -q
%patch0 -p1
NOCONFIGURE=1 ./autogen.sh
%configure --with-release=%{release}

%build
make all %{?_smp_mflags}

%install
%make_install
%find_lang %{name} langfiles

%fdupes %{buildroot}/%{_prefix}

%files -n %{name}-%{_libvrs}  -f langfiles
%doc AUTHORS README.md
%license LICENSE

%{_libdir}/%{name}.so.*

%files devel
%{_libdir}/%{name}.so
%dir %{_datadir}/pw3270
%dir %{_datadir}/pw3270/pot
%{_datadir}/pw3270/pot/*.pot
%{_includedir}/*.h
%{_includedir}/%{name}
%{_libdir}/pkgconfig/*.pc

%post -n %{name}-%{_libvrs} -p /sbin/ldconfig
%postun -n %{name}-%{_libvrs} -p /sbin/ldconfig

%changelog
* Wed Nov 18 2020 Perry Werneck <perry.werneck@gmail.com>
- Fixing CRL download engine
  * Added fix-crl-get-engine.patch
* Sat Oct 31 2020 perry.werneck@gmail.com
- Update to version 5.3+git20201030:
  * Fixing SSL connect error messages.
  * Updating README.md
  * Adding property methods.
  * Adding method to get translated cursor position.
  * Updating get host and get service methods.
  * Allowing extended actions.
  * On TN3270-E the model name should be "IBM-3279-4-E" and not "IBM-3279-4"
  * Adding new SSL state active when downloading CRL.
  * Moving SSL related method to their own include file.
  * Removing unused code.
  * Adding auto-cleanup macro for windows registry.
  * Creating include dir and files based on operating system.
  * Fixing charset conversion.
  * wait_for_ready should wait for "reconnect" process to complete.
  * Fixing popup dialog when connection fails.
  * Host connect now respects timeout.
  * Fixing keyboard lock status and program messages issues.
  * Adding property to enable/disable the CRL download.
  * Looking for performance issues in lib3270_wait_for_ready.
  * Fixing timers.
  * Refactoring timer engine to avoid an abnormal delay when calling wait_for_ready on windows.
  * Adding userdata pointer on timer handle.
  * Enabling dstrace by testprogram command-line option.
  * Refactoring network subsystem for modularity.
  * Updating popup handler replacement (required for IPC modules).
  * Removing unnecessary callbacks from table.
  * Refactoring and centralizing auto-reconnect feature.
  * Using standard popup as default for ssl error.
  * Adding retry option in the connection failed dialog.
  * Refactoring popup engine.
  * Removing unused D-Bus references. Updating keytable.
  * Setting default keyvalue for PAs.
  * Adding PA Key actions on the keytable.
  * Clear & Kybdreset were missing in v3270's accelerator dialogs.
  * Fixing unexpected hangs on windows version.
* Thu Jun  4 2020 perry.werneck@gmail.com
- Update to version 5.3:
  * Adding openssl info in the version string.
  * Updating package release based in rpm release.
  * Setting version strings from configure.
  * Adding method to get the build timestamp; usefull for version checks.
  * Implementing property to get/set the min/max ssl supported protocol version.
  * Can't connect to an empty host or service name.
  * Build instructions for macOS
  * Replacing "<ctrl>" for "<Primary" in keytable definition.
  * Adding option to disable automatic download of the CRL.
  * Adds support for macosx
  * Change name of wait callback type to avoid collision with mac system type
  * Include test for presence of malloc.h
  * Fix warning with autoconf > 2.68
  * Adding more trace information on "connect" process.
  * Fixing null module on log manager.
  * Updating smart paste summary.
  * Fixing action labels.
  * Moving to lib3270 own translations.
  * Fixing unlock-delay property.
  * Fixing exports.
  * Small adjustments in toggles labels and descriptions.
  * Adding more translation methods.
  * Adding methods to get translated properties.
  * Creating lib3270's own translation files.
  * Fixing action group error.
  * Adding signals for save/print copy actions.
  * Removing print/save actions from the protocol library; it's better to implement then on the gui application.
  * Fixing reconnect action label & description.
  * Adding convenience method for open windows registry.
  * Fixing status of "reconnect" action.
  * Preventing emit of "save-settings" signal on v3270 when the host URL is set to the same value.
  * Fixing action descriptions.
  * Using spec-cleaner on lib3270.spec
  * Cleaning up unused code.
  * Fixing error when the selection format toggle is activated with an active selection.
  * Tracing connection state changes.
  * Adding method to get "paste-next" state.
  * Adding new action group for clipboard content availability.
  * Exporting action group notifier for use by libv3270.
  * Using only alfanumeric chars to translate toggle names.
  * Some actions requires more than one accelerator.
  * Improving trace of the http download engine; adding some proxy support.
  * Adjusting property names.
  * Adding host-type property as an unsigned int value for saving it in the session properties.
  * Adding default values for properties.
  * Allow to override build date with SOURCE_DATE_EPOCH
  * Adding more CG chars in the test pattern.
  * Addin APL chars 0xF1 to 0xF9 on test pattern.
  * Grouping property descriptors.
  * Adding method to get property descriptor by name.
  * Refactoring "lunames" property.
  * Activating auto-connect when the corresponding toggle is set and the session is offline.
  * Adding method to get the toggle descriptor from id.
  * Refactoring LU properties.
  * Adjustments on charset API.
  * Color type should be an unsigned int.
  * Fixing action name issue detected on the main application.
  * Adding option for default property value.
  * Improving the model number property.
  * Fixing windows build.
  * Fixing typeahead problem.
  * Adding method to get the "activatable" state of an action group.
  * Fixing "formatted-screen" actions.
  * Fixing "locked" signal on disconnect.
  * Updating action table.
  * Adding events for cursor state.
  * Fixing issue with "selection" actions.
  * Fixing problem with the select/unselect notifications.
  * Adding action types.
  * Adding listeners for action group state changes (required for the new UI).
  * Cleaning unused methods.
  * Fixing segfault on CRL download.
  * Use of curl is now default on linux.
  * Small message adjustment.
  * Fixing CRL download using curl.
  * Splitting windows HTTP download method.
  * Fixes from comments on OBS Request https://build.opensuse.org/request/show/736258
  * CRL check is now default.
  * Adjustments in the SSL negotiation.
  * Releasing CRL on URL change.
  * Adding callback for URL change.
  * Refactoring CRL download method.
  * Organizing CRL check engine to avoid duplications.
  * Fixing warnings and SSL information dialogs.
  * Refactoring CRL check engine.
  * Adding action groups (required for GAction implementatin).
  * Creating and using standard chained list managers.
  * Changint toogle descriptor type name to a more standard one.
  * Changing toggle id type name.
  * Update README.md
  * Fixing icon names.
  * Fixing non-ssl builds.
  * Adjustments in the action API & property tables.
  * Fixing errno use in "has_selection" attribute.
  * Adding method to get property description & summary.
  * Fixing name conflict with the "autoreconnect" toggle and the "reconnect" action.
  * Refactoring actions as properties (easier for language bindings).
  * Adding method to set field and jump to next.
  * Refactoring action table.
  * Adding id in the toggle id description. Required for dynamic attributes.
  * Fixing thread issue on custom certificate loading.
  * Adding method to build filenames independent of the OS.
  * Fixing oversize.
  * Updating sf.
  * Refactoring output buffer management.
  * Adding max witdh & height as read-only properties.
  * Adjustments on screen size changes.
  * Adjustments in the remap engine.
  * Fixing "wait_for_ready" behavior during the "connecting..." state.
  * Fixing conflict with action "connect" and ipc method "connect".
  * Datadir is now based on product name.
  * Adding methods to build data & config file names based in the product name instead of library name.
  * Refactoring charset translation sources.
  * Refacoring toggle engine.
  * Adding lib3270 revision on sdk.
  * Refactoring the action table.
  * Moving charset method to main library.
  * Refactoring action table for use with keyboard preferences dialog.
  * Adding product name in the lib3270 "pc" file.
  * Fixing event trace description.
  * Updating method declarations.
  * Adding oversize setting Updating API.
  * Adding "wait for string" methods Standardizing API Calls
  * Addint method to wait for screen content.
  * Updating documentation, adjusting return codes.
  * Fixing syslog methods.
  * Splitting property set/get methods.
  * Adding method to disable the "lock on operator error" feature.
  * Disabling unlock delay feature when the ms value is 0.
  * Improving keyboard lock status check.
  * Adding APIs to get keyboard lock state.
  * Decreasing delay in "wait_for_ready" method.
  * Fixing bug in the "wait-for-connect" process.
  * Fixing "connect" delay.
  * Fixing confusing documentation of lib3270_connect.
  * Updating API, adding method to get screen format state.
  * Adding "length" parameters in the "set" api calls.
  * Adding ssl state property.
  * Adjustments in the API.
  * Refactoring build process.
  * Adding build option to disable SSL error notifications.
  * Refactoring toggle api calls.
  * Adding option to get the entire terminal window as selection.
  * Default print and save methods now show a warning popup.
  * Emiting notification when SSL validation fails.
  * Adding callback to let the application (or user) to decide if the connection will continue on SSL error.
  * Adding option to use syslog (when available).
  * Moving event source to global to avoid segfault when writing logs before session creation.
  * Log messages are now sent to windows event log.
  * Language bindings library is now part of the IPC plugin package.
  * Small changes in the paste methods.
  * Adjustments in selection data.
  * Adding documentation and return code on input string method.
  * Adding new method to translate the windows error codes.
  * Fixing CRL download methods in windows.
  * Moving new selection management methods to protocol library.
  * Adding method to erase selected inputs.
  * Updating clipboard tools.
  * Adding method to get a rectangle with the selected region.
  * Improving cut&paste methods.
  * Updating selection mechanism.
  * Static library build is now optional and defaults only for windows.
  * Changing "cut" methods to use the same code for "get".
  * Refactoring clipboard management.
  * Adding library name on pkg-config description file (some language binding need it for dynamic loading).
  * Fixing "keep-selected" flag behavior.
  * Updating package to follow naming guidelines.
* Mon Oct  7 2019 Ismail Dönmez <idonmez@suse.com>
- Cleanup spec file
- Disable support for <= SLE12-SP2
* Tue Oct  1 2019 Jan Engelhardt <jengelh@inai.de>
- Enable parallel build. Remove pointless %%pre scriptlet.
- Adjust RPM groups. Remove leading empty line in descriptions.
- Modernize some macro uses.
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
* Fri May 31 2019 perry.werneck@gmail.com
- Update to version 5.2:
  * Updating read me
  * Fixing windows build.
  * Fixing build on OpenSUSE Factory & Tumbleweed.
  * Removing warnings.
  * Fixing error on select from keyboard.
  * Atualizando documentação.
  * Fixing segfault on key pressed on locked terminal.
  * Updating doxygen comments.
  * Fixing segfault when user press enter on a locked terminal.
  * Updating service file.
* Tue Mar 26 2019 Perry Werneck <perry.werneck@gmail.com>
- Fixing osc source_validator errors.
* Thu Feb 28 2019 Perry Werneck <perry.werneck@gmail.com>
  * Project URL changes to github.
  * Fixing deb builds.
  * Updating deb package.
  * Fixing CRL expiration test.
  * Fixing build issues.
  * Small adjustment in CRL validation.
  * Fixing portability issue.
  * Updating locale gen.
  * Fixing CRL expiration problem.
  * Updating pushtag scripts.
* Wed Feb 27 2019 Perry Werneck <perry.werneck@gmail.com>
  * Refactoring build process.
  * Spliting protocol library from pw3270 main project
